summaryrefslogtreecommitdiff
path: root/sc/source/ui/unoobj
diff options
context:
space:
mode:
authorTomaž Vajngerl <tomaz.vajngerl@collabora.co.uk>2018-04-23 12:43:54 +0900
committerTomaž Vajngerl <quikee@gmail.com>2018-04-26 18:19:32 +0200
commit45f20a893a457a40604207382611afd2f8e4b635 (patch)
tree0604a60593c9b9037c8a8e8e3cd3573070dc394b /sc/source/ui/unoobj
parente87ea03a0d595ed478f281a723a6889228babeb2 (diff)
[API CHANGE] deprecate XGraphicObjectResolver
XGraphicObjectResolver was used to get the GraphicObject URL from an storage (package) URL. This isn't possible anymore in LO 6.1 since creating GraphicObject from uniqueID was removed for its lifecycle issues. XGraphicObjectResolver is now deprecated and when the "resolveGraphicObjectURL" is called, it throws a RuntimeExeption. In places where XGraphicObjectResolver was used, we now use the XGraphicStorageHandler as the alternative. Both share a common implementation so previously we could cast one to the other at any time. Now only XGraphicStorageHandler is used. GraphicObjectResolver was removed and replaced by the alternative GraphicStorageHandler for instance creation - where needed. Change-Id: I5d3f759c6f95b7dbe2d93688d99c8aa4899ffa84 Reviewed-on: https://gerrit.libreoffice.org/53279 Reviewed-by: Tomaž Vajngerl <quikee@gmail.com> Tested-by: Tomaž Vajngerl <quikee@gmail.com>
Diffstat (limited to 'sc/source/ui/unoobj')
-rw-r--r--sc/source/ui/unoobj/servuno.cxx14
1 files changed, 7 insertions, 7 deletions
diff --git a/sc/source/ui/unoobj/servuno.cxx b/sc/source/ui/unoobj/servuno.cxx
index 8b958791c16c..37186b02be7c 100644
--- a/sc/source/ui/unoobj/servuno.cxx
+++ b/sc/source/ui/unoobj/servuno.cxx
@@ -48,7 +48,7 @@
#include <tokenuno.hxx>
#include <PivotTableDataProvider.hxx>
// Support creation of GraphicObjectResolver and EmbeddedObjectResolver
#include <svx/xmleohlp.hxx>
#include <svx/xmlgrhlp.hxx>
#include <sfx2/docfile.hxx>
@@ -283,9 +283,9 @@ const ProvNamesId_Type aProvNamesId[] =
{ "com.sun.star.image.ImageMapCircleObject", Type::IMAP_CIRC },
{ "com.sun.star.image.ImageMapPolygonObject", Type::IMAP_POLY },
- // Support creation of GraphicObjectResolver and EmbeddedObjectResolver
- { "com.sun.star.document.ExportGraphicObjectResolver", Type::EXPORT_GOR },
- { "com.sun.star.document.ImportGraphicObjectResolver", Type::IMPORT_GOR },
+ // Support creation of GraphicStorageHandler and EmbeddedObjectResolver
+ { "com.sun.star.document.ExportGraphicStorageHandler", Type::EXPORT_GRAPHIC_STORAGE_HANDLER },
+ { "com.sun.star.document.ImportGraphicStorageHandler", Type::IMPORT_GRAPHIC_STORAGE_HANDLER },
{ "com.sun.star.document.ExportEmbeddedObjectResolver", Type::EXPORT_EOR },
{ "com.sun.star.document.ImportEmbeddedObjectResolver", Type::IMPORT_EOR },
@@ -500,11 +500,11 @@ uno::Reference<uno::XInterface> ScServiceProvider::MakeInstance(
xRet.set(SvUnoImageMapPolygonObject_createInstance( ScShapeObj::GetSupportedMacroItems() ));
break;
- // Support creation of GraphicObjectResolver and EmbeddedObjectResolver
- case Type::EXPORT_GOR:
+ // Support creation of GraphicStorageHandler and EmbeddedObjectResolver
+ case Type::EXPORT_GRAPHIC_STORAGE_HANDLER:
xRet.set(static_cast<cppu::OWeakObject *>(new SvXMLGraphicHelper( SvXMLGraphicHelperMode::Write )));
break;
- case Type::IMPORT_GOR:
+ case Type::IMPORT_GRAPHIC_STORAGE_HANDLER:
xRet.set(static_cast<cppu::OWeakObject *>(new SvXMLGraphicHelper( SvXMLGraphicHelperMode::Read )));
break;
case Type::EXPORT_EOR:
@@ -48,7 +48,7 @@
#include <tokenuno.hxx>
#include <PivotTableDataProvider.hxx>
-// Support creation of GraphicObjectResolver and EmbeddedObjectResolver
+// Support creation of GraphicStorageHandler and EmbeddedObjectResolver
#include <svx/xmleohlp.hxx>
#include <svx/xmlgrhlp.hxx>